..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

Glossary
--------

.. glossary::


    icon
      A small picture that represents some functionality in a computer
      program. A user clicks on an icon to cause an action to be performed
      by a program.

    widget
      A visual element of a graphical user interface that allows a user to
      give commands to an executing program. Example widgets include a
      ``command button``, a ``slider bar``, or a ``list box``.

    graphical user interface
      A user interacts with a computer program by pointing, clicking, and
      dragging icons and widgets in a window on a computer screen.

    GUI
      An abbreviation for a "graphical user interface."

    event-driven programming
      A program that only executes tasks when a user specially requests a task.

    event loop
      A built-in function of a GUI toolkit that "listens" for operating
      system events and then calls an appropriate event-handler for each event.

    event-handler
      A function that processes an event. These functions are also called
      ``callback functions``.


